@@ -325,7 +325,7 @@ async def test_process_image(
     result = await backend.process_image(mock_image)
 
     assert isinstance(result, ExtractionResult)
-    assert "Sample text 1 Sample text 2" in result.content
+    assert result.content == "Sample text 1\nSample text 2"
     assert result.mime_type == "text/plain"
     assert result.metadata.get("width") == 100
     assert result.metadata.get("height") == 100
@@ -358,7 +358,7 @@ async def test_process_image_with_options(backend: PaddleBackend, mock_image: Mo
     )
 
     assert isinstance(result, ExtractionResult)
-    assert "Sample text 1 Sample text 2" in result.content
+    assert result.content == "Sample text 1\nSample text 2"
 
 
 @pytest.mark.anyio
@@ -407,7 +407,7 @@ async def test_process_file(backend: PaddleBackend, mock_run_sync: Mock, ocr_ima
     result = await backend.process_file(ocr_image)
 
     assert isinstance(result, ExtractionResult)
-    assert "Sample text 1 Sample text 2" in result.content
+    assert result.content == "Sample text 1\nSample text 2"
 
 
 @pytest.mark.anyio
@@ -436,7 +436,7 @@ async def test_process_file_with_options(backend: PaddleBackend, mock_run_sync:
     )
 
     assert isinstance(result, ExtractionResult)
-    assert "Sample text 1 Sample text 2" in result.content
+    assert result.content == "Sample text 1\nSample text 2"
 
 
 @pytest.mark.anyio
@@ -673,9 +673,6 @@ def test_validate_language_code_invalid(invalid_language_code: str) -> None:
 @pytest.mark.anyio
 async def test_process_image_grayscale_conversion() -> None:
     """Test grayscale to RGB conversion - covers lines 130-133."""
-    from unittest.mock import Mock, patch
-
-    from PIL import Image
 
     backend = PaddleBackend()
 
@@ -700,8 +697,6 @@ async def test_process_image_grayscale_conversion() -> None:
 @pytest.mark.anyio
 async def test_process_paddle_result_current_line_handling() -> None:
     """Test current line handling in result processing - covers lines 198-201."""
-    from PIL import Image
-
     test_image = Image.new("RGB", (200, 100), color="white")
 
     mock_results = [
@@ -855,3 +850,53 @@ async def test_init_paddle_ocr_with_invalid_language(
     assert "supported_languages" in excinfo.value.context
 
     assert "not supported by PaddleOCR" in str(excinfo.value)
+
+
+def test_process_image_sync(backend: PaddleBackend) -> None:
+    """Test sync image processing."""
+    from unittest.mock import Mock, patch
+
+    image = Image.new("RGB", (100, 100))
+
+    mock_paddle = Mock()
+    mock_paddle.ocr.return_value = [
+        [
+            [
+                [[0, 0], [100, 0], [100, 20], [0, 20]],
+                ("Sample OCR text", 0.95),
+            ]
+        ]
+    ]
+
+    with patch.object(backend, "_init_paddle_ocr_sync"), patch.object(backend, "_paddle_ocr", mock_paddle):
+        result = backend.process_image_sync(image)
+
+        assert isinstance(result, ExtractionResult)
+        assert result.content.strip() == "Sample OCR text"
+        assert result.metadata["width"] == 100
+        assert result.metadata["height"] == 100
+
+
+def test_process_file_sync(backend: PaddleBackend, tmp_path: Path) -> None:
+    """Test sync file processing."""
+    from unittest.mock import Mock, patch
+
+    test_image = Image.new("RGB", (100, 100))
+    image_path = tmp_path / "test_image.png"
+    test_image.save(image_path)
+
+    mock_paddle = Mock()
+    mock_paddle.ocr.return_value = [
+        [
+            [
+                [[0, 0], [100, 0], [100, 20], [0, 20]],
+                ("Sample file text", 0.90),
+            ]
+        ]
+    ]
+
+    with patch.object(backend, "_init_paddle_ocr_sync"), patch.object(backend, "_paddle_ocr", mock_paddle):
+        result = backend.process_file_sync(image_path)
+
+        assert isinstance(result, ExtractionResult)
+        assert result.content.strip() == "Sample file text"
